// luma.gl
// SPDX-License-Identifier: MIT
// Copyright (c) vis.gl contributors
// shadertools exports
/**
 * Marks GLSL shaders for syntax highlighting: glsl`...`
 * Install https://marketplace.visualstudio.com/items?itemName=boyswan.glsl-literal
 */
export { glsl } from "./lib/glsl-utils/highlight.js";
export { ShaderModuleInstance } from "./lib/shader-module/shader-module-instance.js";
// ShaderAssembler
export { ShaderAssembler } from "./lib/shader-assembler.js";
export { normalizeShaderModule } from "./lib/shader-module/normalize-shader-module.js";
// SHADER HELPERS
// Shader source introspection
export { getShaderInfo } from "./lib/glsl-utils/get-shader-info.js";
export { getQualifierDetails, getPassthroughFS, typeToChannelSuffix, typeToChannelCount, convertToVec4 } from "./lib/glsl-utils/shader-utils.js";
export { generateShaderForModule } from "./lib/shader-generator/generate-shader.js";
export { capitalize } from "./lib/shader-generator/utils/capitalize.js";
// TEST EXPORTS - Do not use in production applications
export { assembleShaderPairGLSL } from "./lib/shader-assembly/assemble-shaders.js";
export { ShaderModuleInstance as _ShaderModuleInstance } from "./lib/shader-module/shader-module-instance.js";
export { combineInjects } from "./lib/shader-assembly/shader-injections.js";
export { resolveModules as _resolveModules } from "./lib/shader-assembly/resolve-modules.js";
export { getDependencyGraph as _getDependencyGraph } from "./lib/shader-assembly/resolve-modules.js";
// EXPERIMENTAL WGSL
export { getShaderLayoutFromWGSL } from "./lib/wgsl/get-shader-layout-wgsl.js";
// SHADER MODULES - WEBGL1 VERSION
// utils
// math libraries
export { random } from "./modules/math/random/random.js";
export { fp32 } from "./modules/math/fp32/fp32.js";
export { picking } from "./modules/engine/picking/picking.js";
export { lighting } from "./modules/lighting/lights/lighting-uniforms.js";
export { dirlight } from "./modules/lighting/no-material/dirlight.js";
export { gouraudMaterial } from "./modules/lighting/gouraud-material/gouraud-material.js";
export { phongMaterial } from "./modules/lighting/phong-material/phong-material.js";
// export type {PBRMaterialSettings, PBRMaterialUniforms} from './modules/lighting/pbr-material/pbr';
export { pbrMaterial } from "./modules/lighting/pbr-material/pbr-material.js";
export { brightnessContrast } from "./modules/postprocessing/image-adjust-filters/brightnesscontrast.js";
export { denoise } from "./modules/postprocessing/image-adjust-filters/denoise.js";
export { hueSaturation } from "./modules/postprocessing/image-adjust-filters/huesaturation.js";
export { noise } from "./modules/postprocessing/image-adjust-filters/noise.js";
export { sepia } from "./modules/postprocessing/image-adjust-filters/sepia.js";
export { vibrance } from "./modules/postprocessing/image-adjust-filters/vibrance.js";
export { vignette } from "./modules/postprocessing/image-adjust-filters/vignette.js";
export { tiltShift } from "./modules/postprocessing/image-blur-filters/tiltshift.js";
export { triangleBlur } from "./modules/postprocessing/image-blur-filters/triangleblur.js";
export { zoomBlur } from "./modules/postprocessing/image-blur-filters/zoomblur.js";
export { colorHalftone } from "./modules/postprocessing/image-fun-filters/colorhalftone.js";
export { dotScreen } from "./modules/postprocessing/image-fun-filters/dotscreen.js";
export { edgeWork } from "./modules/postprocessing/image-fun-filters/edgework.js";
export { hexagonalPixelate } from "./modules/postprocessing/image-fun-filters/hexagonalpixelate.js";
export { ink } from "./modules/postprocessing/image-fun-filters/ink.js";
export { magnify } from "./modules/postprocessing/image-fun-filters/magnify.js";
export { bulgePinch } from "./modules/postprocessing/image-warp-filters/bulgepinch.js";
export { swirl } from "./modules/postprocessing/image-warp-filters/swirl.js";
// Postprocessing modules
// export type {FXAAProps} from './modules/postprocessing/fxaa/fxaa';
export { fxaa } from "./modules/postprocessing/fxaa/fxaa.js";
export { warp as _warp } from "./modules/postprocessing/image-warp-filters/warp.js";
// DEPRECATED - v8 legacy shader modules (non-uniform buffer)
// math libraries
export { fp64, fp64arithmetic } from "./modules-webgl1/math/fp64/fp64.js";
// projection and lighting
export { geometry as geometry1 } from "./modules-webgl1/geometry/geometry.js";
export { project as project1 } from "./modules-webgl1/project/project.js";
export { lights as lights1 } from "./modules-webgl1/lighting/lights/lights.js";
export { dirlight as dirlight1 } from "./modules-webgl1/lighting/dirlight/dirlight.js";
export { gouraudLighting, phongLighting } from "./modules-webgl1/lighting/phong-lighting/phong-lighting.js";
export { pbr } from "./modules-webgl1/lighting/pbr/pbr.js";
